@@ -21,8 +21,7 @@ class Aws(VaultApiBase):
 
     def configure(self, max_retries=None, access_key=None, secret_key=None, endpoint=None, iam_endpoint=None,
                   sts_endpoint=None, iam_server_id_header_value=None, mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Configures the credentials required to perform API calls to AWS as well as custom endpoints to talk to AWS
-        API
+        """Configure the credentials required to perform API calls to AWS as well as custom endpoints to talk to AWS API.
 
         The instance identity document fetched from the PKCS#7 signature will provide the EC2 instance ID.
         The credentials configured using this endpoint will be used to query the status of the instances via
@@ -60,7 +59,7 @@ class Aws(VaultApiBase):
             against different types of replay attacks, for example a signed request sent to a dev server being resent
             to a production server
         :type iam_server_id_header_value: str | unicode
-        :param mount_point: The "path" the aws auth method was mounted on
+        :param mount_point: The path the AWS auth method was mounted on.
         :type mount_point: str | unicode
         :return: The response of the request.
         :rtype: requests.Response
@@ -82,12 +81,12 @@ class Aws(VaultApiBase):
         )
 
     def read_config(self, mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Returns the previously configured AWS access credentials
+        """Read previously configured AWS access credentials.
 
         Supported methods:
             GET: /auth/{mount_point}/config. Produces: 200 application/json
 
-        :param mount_point: The "path" the aws auth method was mounted on
+        :param mount_point: The path the AWS auth method was mounted on.
         :type mount_point: str | unicode
         :return: The data key from the JSON response of the request.
         :rtype: dict
@@ -99,12 +98,12 @@ class Aws(VaultApiBase):
         return response.get('data')
 
     def delete_config(self, mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Deletes the previously configured AWS access credentials
+        """Delete previously configured AWS access credentials,
 
         Supported methods:
             DELETE: /auth/{mount_point}/config Produces: 204 (empty body)
 
-        :param mount_point: The "path" the aws auth method was mounted on
+        :param mount_point: The path the AWS auth method was mounted on.
         :type mount_point: str | unicode
         :return: The response of the request.
         :rtype: requests.Response
@@ -116,8 +115,9 @@ class Aws(VaultApiBase):
 
     def configure_identity_integration(self, iam_alias=None, ec2_alias=None,
                                        mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Configures the way that Vault interacts with the Identity store. The default (as of Vault 1.0.3)
-            is role_id for both values
+        """Configure the way that Vault interacts with the Identity store.
+
+        The default (as of Vault 1.0.3) is role_id for both values.
 
         Supported methods:
             POST: /auth/{mount_point}/config/identity Produces: 204 (empty body)
@@ -136,7 +136,7 @@ class Aws(VaultApiBase):
             used. When instance_id is selected, the instance identifier is used as the identity alias name. When
             image_id is selected, AMI ID of the instance is used as the identity alias name
         :type ec2_alias: str | unicode
-        :param mount_point: The "path" the aws auth method was mounted on
+        :param mount_point: The path the AWS auth method was mounted on.
         :type mount_point: str | unicode
         :return: The response of the request
         :rtype: request.Response
@@ -164,12 +164,12 @@ class Aws(VaultApiBase):
         )
 
     def read_identity_integration(self, mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Returns the previously configured identity integration configuration
+        """Return previously configured identity integration configuration.
 
         Supported methods:
             GET: /auth/{mount_point}/config/identity. Produces: 200 application/json
 
-        :param mount_point: The "path" the aws auth method was mounted on
+        :param mount_point: The path the AWS auth method was mounted on.
         :type mount_point: str | unicode
         :return: The data key from the JSON response of the request.
         :rtype: dict
@@ -181,7 +181,7 @@ class Aws(VaultApiBase):
         return response.get('data')
 
     def create_certificate_configuration(self, cert_name, aws_public_cert, document_type=None, mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Registers an AWS public key to be used to verify the instance identity documents
+        """Register AWS public key to be used to verify the instance identity documents.
 
         While the PKCS#7 signature of the identity documents have DSA digest, the identity signature will have RSA
         digest, and hence the public keys for each type varies respectively. Indicate the type of the public key using
@@ -197,7 +197,7 @@ class Aws(VaultApiBase):
         :param document_type: Takes the value of either "pkcs7" or "identity", indicating the type of document which can be
             verified using the given certificate
         :type document_type: string | unicode
-        :param mount_point: The "path" the aws auth method was mounted on
+        :param mount_point: The path the AWS auth method was mounted on.
         :type mount_point: str | unicode
         :return: The response of the request
         :rtype: request.Response
@@ -218,14 +218,14 @@ class Aws(VaultApiBase):
         )
 
     def read_certificate_configuration(self, cert_name, mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Returns the previously configured AWS public key
+        """Return previously configured AWS public key.
 
         Supported methods:
             GET: /v1/auth/{mount_point}/config/certificate/:cert_name Produces: 200 application/json
 
         :param cert_name: Name of the certificate
         :type cert_name: str | unicode
-        :param mount_point: The "path" the aws auth method was mounted on
+        :param mount_point: The path the AWS auth method was mounted on.
         :return: The data key from the JSON response of the request.
         :rtype: dict
         """
@@ -236,14 +236,14 @@ class Aws(VaultApiBase):
         return response.get('data')
 
     def delete_certificate_configuration(self, cert_name, mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Removes the previously configured AWS public key
+        """Remove previously configured AWS public key.
 
         Supported methods:
             DELETE: /auth/{mount_point}/config/certificate/:cert_name Produces: 204 (empty body)
 
         :param cert_name: Name of the certificate
         :type cert_name: str | unicode
-        :param mount_point: The "path" the aws auth method was mounted on
+        :param mount_point: The path the AWS auth method was mounted on.
         :type mount_point: str | unicode
         :return: The response of the request
         :rtype: request.Response
@@ -254,13 +254,15 @@ class Aws(VaultApiBase):
         )
 
     def list_certificate_configurations(self, mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Lists all the AWS public certificates that are registered with the method
+        """List AWS public certificates that are registered with the method.
 
         Supported methods
             LIST: /auth/{mount_point}/config/certificates Produces: 200 application/json
 
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{mount_point}/config/certificates', mount_point=mount_point)
         response = self._adapter.list(
@@ -269,7 +271,7 @@ class Aws(VaultApiBase):
         return response.get('data')
 
     def create_sts_role(self, account_id, sts_role, mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """ Allows the explicit association of STS roles to satellite AWS accounts (i.e. those which are not the
+        """Allow the explicit association of STS roles to satellite AWS accounts (i.e. those which are not the
             account in which the Vault server is running.)
 
             Vault will use credentials obtained by assuming these STS roles when validating IAM principals or EC2
@@ -278,10 +280,16 @@ class Aws(VaultApiBase):
             Supported methods:
                 POST: /v1/auth/{mount_point}/config/sts/:account_id Produces: 204 (empty body)
 
-        :param account_id:
-        :param sts_role:
-        :param mount_point:
-        :return:
+        :param account_id: AWS account ID to be associated with STS role.
+            If set, Vault will use assumed credentials to verify any login attempts from EC2 instances in this account.
+        :type account_id: str
+        :param sts_role: AWS ARN for STS role to be assumed when interacting with the account specified.
+            The Vault server must have permissions to assume this role.
+        :type sts_role: str
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{0}/config/sts/{1}', mount_point, account_id)
         params = {
@@ -294,11 +302,14 @@ class Aws(VaultApiBase):
         )
 
     def read_sts_role(self, account_id, mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Returns the previously configured STS role
+        """Return previously configured STS role.
 
-        :param account_id:
-        :param mount_point:
-        :return:
+        :param account_id: AWS account ID that has been previously associated with STS role.
+        :type account_id: str
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{0}/config/sts/{1}', mount_point, account_id)
         response = self._adapter.get(
@@ -307,10 +318,12 @@ class Aws(VaultApiBase):
         return response.get('data')
 
     def list_sts_roles(self, mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Lists all the AWS Account IDs for which an STS role is registered
+        """List AWS Account IDs for which an STS role is registered.
 
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{mount_point}/config/sts', mount_point=mount_point)
         response = self._adapter.list(
@@ -319,11 +332,13 @@ class Aws(VaultApiBase):
         return response.get('data')
 
     def delete_sts_role(self, account_id, mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Deletes a previously configured AWS account/STS role association
+        """Delete a previously configured AWS account/STS role association.
 
         :param account_id:
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{0}/config/sts/{1}', mount_point, account_id)
         return self._adapter.delete(
@@ -332,12 +347,17 @@ class Aws(VaultApiBase):
 
     def configure_identity_whitelist_tidy(self, safety_buffer=None, disable_periodic_tidy=None,
                                           mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Configures the periodic tidying operation of the whitelisted identity entries
+        """Configure the periodic tidying operation of the whitelisted identity entries.
 
-        :param safety_buffer:
-        :param disable_periodic_tidy:
-        :param mount_point:
-        :return:
+        :param safety_buffer: The amount of extra time that must have passed beyond the roletag expiration, before
+            it is removed from the method storage.
+        :type safety_buffer: str
+        :param disable_periodic_tidy: If set to 'true', disables the periodic tidying of the identity-whitelist/<instance_id> entries.
+        :type disable_periodic_tidy: bool
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{mount_point}/config/tidy/identity-whitelist', mount_point=mount_point)
         params = utils.remove_nones({
@@ -350,10 +370,12 @@ class Aws(VaultApiBase):
         )
 
     def read_identity_whitelist_tidy(self, mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Returns the previously configured periodic whitelist tidying settings
+        """Read previously configured periodic whitelist tidying settings.
 
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{mount_point}/config/tidy/identity-whitelist', mount_point=mount_point)
         response = self._adapter.get(
@@ -362,10 +384,12 @@ class Aws(VaultApiBase):
         return response.get('data')
 
     def delete_identity_whitelist_tidy(self, mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Deletes the previously configured periodic whitelist tidying settings
+        """Delete previously configured periodic whitelist tidying settings.
 
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{mount_point}/config/tidy/identity-whitelist', mount_point=mount_point)
         return self._adapter.delete(
@@ -374,12 +398,17 @@ class Aws(VaultApiBase):
 
     def configure_role_tag_blacklist_tidy(self, safety_buffer=None, disable_periodic_tidy=None,
                                           mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Configures the periodic tidying operation of the blacklisted role tag entries
+        """Configure the periodic tidying operation of the blacklisted role tag entries.
 
-        :param safety_buffer:
-        :param disable_periodic_tidy:
-        :param mount_point:
-        :return:
+        :param safety_buffer: The amount of extra time that must have passed beyond the roletag expiration, before
+            it is removed from the method storage.
+        :type safety_buffer: str
+        :param disable_periodic_tidy: If set to 'true', disables the periodic tidying of the roletag-blacklist/<instance_id> entries.
+        :type disable_periodic_tidy: bool
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{mount_point}/config/tidy/roletag-blacklist', mount_point=mount_point)
         params = utils.remove_nones({
@@ -392,10 +421,12 @@ class Aws(VaultApiBase):
         )
 
     def read_role_tag_blacklist_tidy(self, mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Returns the previously configured periodic blacklist tidying settings
+        """Read previously configured periodic blacklist tidying settings.
 
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{mount_point}/config/tidy/roletag-blacklist', mount_point=mount_point)
         response = self._adapter.get(
@@ -404,10 +435,12 @@ class Aws(VaultApiBase):
         return response.get('data')
 
     def delete_role_tag_blacklist_tidy(self, mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Deletes the previously configured periodic blacklist tidying settings
+        """Delete previously configured periodic blacklist tidying settings.
 
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{mount_point}/config/tidy/roletag-blacklist', mount_point=mount_point)
         return self._adapter.delete(
@@ -421,15 +454,7 @@ class Aws(VaultApiBase):
                     resolve_aws_unique_ids=None, ttl=None, max_ttl=None, period=None, policies=None,
                     allow_instance_migration=None, disallow_reauthentication=None,
                     mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Registers a role in the method. Only those instances or principals which are using the role registered
-            using this endpoint, will be able to perform the login operation
-
-            Constraints can be specified on the role, that are applied on the instances or principals attempting to
-            login. At least one constraint must be specified on the role. The available constraints you can choose
-            are dependent on the auth_type of the role and, if the auth_type is iam, then whether inferencing is
-            enabled. A role will not let you configure a constraint if it is not checked by the auth_type and
-            inferencing configuration of that role. For the constraints which accept a list of values, the
-            authenticating instance/principal must match any one value in the list in order to satisfy that constraint
+        """Register a role in the method.
 
         :param role:
         :param auth_type:
@@ -452,8 +477,10 @@ class Aws(VaultApiBase):
         :param policies:
         :param allow_instance_migration:
         :param disallow_reauthentication:
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{0}/role/{1}', mount_point, role)
         params = {
@@ -492,8 +519,10 @@ class Aws(VaultApiBase):
         """Returns the previously registered role configuration
 
         :param role:
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{0}/role/{1}', mount_point, role)
         response = self._adapter.get(
@@ -504,8 +533,10 @@ class Aws(VaultApiBase):
     def list_roles(self, mount_point=AWS_DEFAULT_MOUNT_POINT):
         """Lists all the roles that are registered with the method
 
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{mount_point}/roles', mount_point=mount_point)
         response = self._adapter.list(
@@ -517,8 +548,10 @@ class Aws(VaultApiBase):
         """Deletes the previously registered role
 
         :param role:
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{0}/role/{1}', mount_point, role)
         return self._adapter.delete(
@@ -547,8 +580,10 @@ class Aws(VaultApiBase):
         :param instance_id:
         :param allow_instance_migration:
         :param disallow_reauthentication:
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{0}/role/{1}/tag', mount_point, role)
 
@@ -575,8 +610,15 @@ class Aws(VaultApiBase):
             role with which the login is being performed. With the ec2 auth method, as an alternative to pkcs7
             signature, the identity document along with its RSA digest can be supplied to this endpoint
 
-        :param mount_point:
-        :return:
+        :param role: Name of the role against which the login is being attempted.
+        :type role: str
+        :param use_token: if True, uses the token in the response received from the auth request to set the "token"
+            attribute on the the :py:meth:`hvac.adapters.Adapter` instance under the _adapater Client attribute.
+        :type use_token: bool
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{mount_point}/login', mount_point=mount_point)
 
@@ -601,12 +643,21 @@ class Aws(VaultApiBase):
         )
 
     def ec2_login(self, pkcs7, nonce=None, role=None, use_token=True, mount_point=AWS_DEFAULT_MOUNT_POINT):
-        """Fetch a token
-        :param pkcs7:
-        :param nonce:
-        :param role:
-        :param use_token:
-        :param mount_point:
+        """Retrieve a Vault token using an AWS authentication method mount's EC2 role.
+
+        :param pkcs7: PKCS7 signature of the identity document with all newline characters removed.
+        :type pkcs7: str
+        :param nonce: The nonce to be used for subsequent login requests.
+        :type nonce: str
+        :param role: Name of the role against which the login is being attempted.
+        :type role: str
+        :param use_token: if True, uses the token in the response received from the auth request to set the "token"
+            attribute on the the :py:meth:`hvac.adapters.Adapter` instance under the _adapater Client attribute.
+        :type use_token: bool
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{mount_point}/login', mount_point=mount_point)
         params = {
@@ -631,8 +682,10 @@ class Aws(VaultApiBase):
             does not invalidate the already issued token
 
         :param role_tag:
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{0}/roletag-blacklist/{1}', mount_point, role_tag)
         return self._adapter.post(
@@ -643,8 +696,10 @@ class Aws(VaultApiBase):
         """Returns the blacklist entry of a previously blacklisted role tag
 
         :param role_tag:
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{0}/roletag-blacklist/{1}', mount_point, role_tag)
         response = self._adapter.get(
@@ -655,8 +710,10 @@ class Aws(VaultApiBase):
     def list_blacklist_tags(self, mount_point=AWS_DEFAULT_MOUNT_POINT):
         """Lists all the role tags that are blacklisted
 
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{mount_point}/roletag-blacklist', mount_point=mount_point)
         response = self._adapter.list(
@@ -668,8 +725,10 @@ class Aws(VaultApiBase):
         """Deletes a blacklisted role tag
 
         :param role_tag:
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{0}/roletag-blacklist/{1}', mount_point, role_tag)
         return self._adapter.delete(
@@ -680,8 +739,10 @@ class Aws(VaultApiBase):
         """Cleans up the entries in the blacklist based on expiration time on the entry and safety_buffer
 
         :param saftey_buffer:
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{mount_point}/tidy/roletag-blacklist', mount_point=mount_point)
         params = {
@@ -696,8 +757,10 @@ class Aws(VaultApiBase):
         """Returns an entry in the whitelist. An entry will be created/updated by every successful login
 
         :param instance_id:
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{0}/identity-whitelist/{1}', mount_point, instance_id)
         response = self._adapter.get(
@@ -708,8 +771,10 @@ class Aws(VaultApiBase):
     def list_identity_whitelist(self, mount_point=AWS_DEFAULT_MOUNT_POINT):
         """Lists all the instance IDs that are in the whitelist of successful logins
 
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{mount_point}/identity-whitelist', mount_point=mount_point)
         response = self._adapter.list(
@@ -721,8 +786,10 @@ class Aws(VaultApiBase):
         """Deletes a cache of the successful login from an instance
 
         :param instance_id:
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{0}/identity-whitelist/{1}', mount_point, instance_id)
         return self._adapter.delete(
@@ -733,8 +800,10 @@ class Aws(VaultApiBase):
         """Cleans up the entries in the whitelist based on expiration time and safety_buffer
 
         :param saftey_buffer:
-        :param mount_point:
-        :return:
+        :param mount_point: The path the AWS auth method was mounted on.
+        :type mount_point: str
+        :return: The response of the request.
+        :rtype: requests.Response
         """
         api_path = utils.format_url('/v1/auth/{mount_point}/tidy/identity-whitelist', mount_point=mount_point)
         params = {
